//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by res.rc
//
#define CLOSE_BUTTON                    1
#define BUTTON_CLOSE                    1
#define BTN_CLOSE                       1
#define MENU_OPEN_FILE                  100
#define EDIT_ROM                        100
#define LBL_LOG_TEXT                    100
#define LBL_CDLOGGER_CODECOUNT          100
#define CHECK_PALETTE_ENABLED           100
#define GRP_GAMEPAD1                    100
#define IDC_TRACER_LOG                  100
#define MENU_MV_FILE_SAVE               100
#define IDC_ROMPATCHER_OFFSET_BOX       100
#define IDC_ASSEMBLER_HISTORY           100
#define LBL_DWBDIALOG_TEXT              100
#define MENU_CLOSE_FILE                 101
#define CB_DISABLE_SPEED_THROTTLING     101
#define LBL_CDLOGGER_DATACOUNT          101
#define GRP_PPUVIEW_TABLES              101
#define IDC_NETMOO_STATUS               101
#define GRP_GAMEPAD2                    101
#define IDC_LIST_CHEATS                 101
#define IDC_SCRL_TRACER_LOG             101
#define MENU_MV_FILE_SAVE_AS            101
#define IDC_VIDEOCONFIG_FS              101
#define IDC_DEBUGGER_BP_ADD             101
#define IDC_ROMPATCHER_DOTNES_OFFSET    101
#define IDC_NTVIEW_TABLE_BOX            101
#define IDC_ASSEMBLER_DISASSEMBLY       101
#define EDIT_BATTERY                    101
#define MENU_RECENT_FILES               102
#define CB_LOAD_FILE_OPEN               102
#define LBL_CDLOGGER_UNDEFCOUNT         102
#define IDC_PPUVIEW_SCANLINE            102
#define IDC_NETMOO_CMD_INPUT            102
#define IDC_CHEAT_ADDR                  102
#define IDC_BTN_START_STOP_LOGGING      102
#define MENU_MV_FILE_LOAD_TBL           102
#define IDC_VIDEOCONFIG_AUTO_FS         102
#define IDC_DEBUGGER_BP_DEL             102
#define IDC_ADDBP_MODE_R                102
#define IDC_ROMPATCHER_OFFSET           102
#define IDC_NTVIEW_SCANLINE             102
#define IDC_ASSEMBLER_PATCH_DISASM      102
#define CHECK_PALETTE_GRAYSCALE         102
#define EDIT_STATE                      102
#define BTN_CDLOGGER_RESET              103
#define LBL_PPUVIEW_TILE1               103
#define IDC_CHEAT_VAL                   103
#define IDC_RADIO_LOG_LAST              103
#define MENU_MV_FILE_UNLOAD_TBL         103
#define IDC_DEBUGGER_BP_EDIT            103
#define IDC_ADDBP_MODE_W                103
#define IDC_ROMPATCHER_BTN_EDIT         103
#define IDC_NTVIEW_PROPERTIES_LINE_1    103
#define IDC_VIDEOCONFIG_HIDEMOUSE       103
#define EDIT_FDSBIOS                    103
#define CB_AUTO_HIDE_MENU               104
#define COMBO_PAD1                      104
#define BTN_CDLOGGER_LOAD               104
#define LBL_PPUVIEW_TILE2               104
#define IDC_CHEAT_NAME                  104
#define IDC_RADIO_LOG_TO_FILE           104
#define MENU_MV_FILE_DUMP_RAM           104
#define IDC_VIDEOCONFIG_SYNC_METHOD_WIN 104
#define IDC_DEBUGGER_RUN                104
#define IDC_ADDBP_MODE_X                104
#define IDC_ROMPATCHER_CURRENT_DATA_BOX 104
#define IDC_NTVIEW_PROPERTIES_LINE_2    104
#define CHECK_PALETTE_CUSTOM            104
#define EDIT_SCREENSHOT                 104
#define COMBO_PAD2                      105
#define CB_SET_HIGH_PRIORITY            105
#define BTN_CDLOGGER_START_PAUSE        105
#define LBL_PPUVIEW_PALETTES            105
#define IDC_CHEAT_VAL_KNOWN             105
#define MENU_MV_FILE_DUMP_PPU           105
#define IDC_VIDEOCONFIG_SYNC_METHOD_FS  105
#define IDC_DEBUGGER_STEP_IN            105
#define IDC_TRACER_LOG_SIZE             105
#define IDC_ADDBP_MEM_CPU               105
#define IDC_ROMPATCHER_CURRENT_DATA     105
#define IDC_NTVIEW_PROPERTIES_LINE_3    105
#define EDIT_CHEAT                      105
#define BTN_PORT1                       106
#define BTN_CDLOGGER_SAVE_AS            106
#define IDC_CHEAT_LIST_POSSIBILITIES    106
#define IDC_VIDEOCONFIG_CLIPSIDES       106
#define IDC_DEBUGGER_STEP_OUT           106
#define IDC_ADDBP_MEM_PPU               106
#define IDC_NTVIEW_PROPERTIES_LINE_4    106
#define IDC_TEXT_LINES_TO_THIS_WINDOW   106
#define EDIT_MOVIE                      106
#define BTN_PORT2                       107
#define BTN_CDLOGGER_SAVE               107
#define IDC_DEBUGGER_STEP_OVER          107
#define IDC_ADDBP_MEM_SPR               107
#define IDC_ROMPATCHER_DISASSEMBLY      107
#define IDC_VIDEOCONFIG_BESTFIT         107
#define EDIT_MEMWATCH                   107
#define IDR_ACCELERATOR1                108
#define BTN_CDLOGGER_SAVE_STRIPPED      108
#define IDC_CHEAT_VAL_NE_BY             108
#define IDC_DEBUGGER_SEEK_PC            108
#define IDR_TASEDITOR_ACCELERATORS      108
#define IDC_VIDEOCONFIG_CONSOLE_BGCOLOR 108
#define EDIT_BOT                        108
#define IDC_CHEAT_VAL_GT_BY             109
#define IDC_DEBUGGER_SEEK_TO            109
#define IDC_ROMPATCHER_PATCH_DATA       109
#define IDC_ADDBP_MODE_F                109
#define BTN_CDLOGGER_SAVE_UNUSED        109
#define IDC_VIDEOCONFIG_TVASPECT        109
#define IDC_GROUP_LOG_OPTIONS           109
#define EDIT_MACRO                      109
#define IDC_CHEAT_VAL_LT_BY             110
#define MENU_SAVE_STATE                 110
#define CB_ASK_EXIT                     110
#define COMBO_FAM                       110
#define IDB_TE_ARROW                    110
#define IDC_CHECK_LOG_REGISTERS         110
#define IDC_DEBUGGER_BREAK_ON_BAD_OP    110
#define IDC_ROMPATCHER_BTN_APPLY        110
#define LBL_CDLOGGER_RENDERCOUNT        110
#define IDC_VIDEOCONFIG_SQUARE_PIXELS   110
#define EDIT_PRESET                     110
#define MENU_LOAD_STATE                 111
#define CB_DISABLE_SCREEN_SAVER         111
#define BTN_FAM                         111
#define IDC_CHECK_LOG_PROCESSOR_STATUS  111
#define IDC_DEBUGGER_RELOAD_SYMS        111
#define IDC_ROMPATCHER_BTN_SAVE         111
#define IDC_CHEAT_COM                   111
#define IDC_VIDEOCONFIG_DIRECTDRAW_FS   111
#define EDIT_LUA                        111
#define BTN_AUTO_HOLD                   112
#define IDC_BTN_LOG_BROWSE              112
#define IDC_DEBUGGER_BOOKMARK_ADD       112
#define IDC_VIDEOCONFIG_DIRECTDRAW_WIN  112
#define EDIT_AVI                        112
#define IDC_DEBUGGER_BOOKMARK_DEL       113
#define IDC_EXTRA_LOG_OPTIONS           113
#define EDIT_ROOT                       113
#define BTN_CLEAR_AH                    114
#define IDC_CHECK_LOG_NEW_INSTRUCTIONS  114
#define IDC_DEBUGGER_RUN_LINE           114
#define LBL_CDLOGGER_VROMREADCOUNT      114
#define LBL_AUTO_HOLD                   115
#define IDC_CHECK_LOG_NEW_DATA          115
#define IDC_DEBUGGER_RUN_FRAME2         115
#define LBL_CDLOGGER_UNDEFVROMCOUNT     115
#define LBL_CLEAR_AH                    116
#define IDC_CHECK_LOG_UPDATE_WINDOW     116
#define IDC_DEBUGGER_RESET_COUNTERS     116
#define CHEAT_CONTEXT_LIST_TOGGLECHEAT  117
#define IDC_DEBUGGER_BREAK_ON_CYCLES    117
#define IDC_CHECK_CODE_TABBING          117
#define CHEAT_CONTEXT_LIST_POKECHEATVALUE 118
#define IDC_CHECK_LOG_STATUSES_TO_THE_LEFT 118
#define IDC_DEBUGGER_BOOKMARK_EDIT      118
#define CHEAT_CONTEXT_LIST_GOTOINHEXEDITOR 119
#define IDC_DEBUGGER_BREAK_ON_INSTRUCTIONS 119
#define IDC_CHECK_LOG_FRAMES_COUNT      119
#define IDC_CHECK_LOG_CYCLES_COUNT      120
#define CHEAT_CONTEXT_LIST_DELETESELECTEDCHEATS 120
#define IDC_CHECK_LOG_INSTRUCTIONS_COUNT 121
#define COMBO_SOUND_8BIT                122
#define IDC_CHECK_SYMBOLIC_TRACING      123
#define CHECK_SOUND_GLOBAL_FOCUS        124
#define IDC_CHECK_LOG_MESSAGES          124
#define IDC_CHECK_LOG_BREAKPOINTS       125
#define CHECK_SOUND_ENABLED             126
#define CTL_LATENCY_TRACKBAR            128
#define COMBO_SOUND_QUALITY             129
#define CHECK_SOUND_MUTEFA              130
#define DEBUGGER_CONTEXT_TOGGLEBREAK    132
#define MENU_RECORD_MOVIE               141
#define MENU_REPLAY_MOVIE               142
#define MENU_STOP_MOVIE                 143
#define MENU_RECORD_AVI                 151
#define MENU_STOP_AVI                   152
#define MENU_EXIT                       153
#define IDD_RAMSEARCH                   154
#define IDD_RAMWATCH                    155
#define IDD_EDITWATCH                   156
#define IDR_RWACCELERATOR               158
#define IDD_LUA                         159
#define IDB_BITMAP0                     163
#define IDB_BITMAP1                     164
#define IDB_BITMAP2                     165
#define IDB_BITMAP3                     166
#define IDB_BITMAP4                     167
#define IDB_BITMAP5                     168
#define IDB_BITMAP6                     169
#define IDB_BITMAP7                     170
#define IDB_BITMAP8                     171
#define IDB_BITMAP9                     172
#define IDB_BITMAP10                    173
#define IDB_BITMAP11                    174
#define IDB_BITMAP12                    175
#define IDB_BITMAP13                    176
#define IDB_BITMAP14                    177
#define IDB_BITMAP15                    178
#define IDB_BITMAP16                    179
#define IDB_BITMAP17                    180
#define IDB_BITMAP18                    181
#define IDB_BITMAP19                    182
#define IDB_BRANCH_SPRITESHEET          184
#define IDD_TASEDITOR_SAVECOMPACT       195
#define IDD_TASEDITOR_EXPORT            196
#define IDI_ICON3                       197
#define IDD_TASEDITOR_FINDNOTE          198
#define IDD_TASEDITOR_ABOUT             199
#define MENU_RESET                      200
#define BUTTON_ROM                      200
#define TXT_PAD1                        200
#define BTN_RESTORE_DEFAULTS            200
#define BTN_CLEAR                       200
#define IDC_EDIT_FILENAME               200
#define IDC_COMBO_FILENAME              200
#define BTN_PALETTE_LOAD                200
#define IDC_NETMOO_HOST                 200
#define COMBO_SOUND_RATE                200
#define MENU_MV_EDIT_UNDO               200
#define IDC_VIDEOCONFIG_XRES            200
#define IDC_DEBUGGER_FLAG_N             200
#define IDC_ADDBP_ADDR_START            200
#define MENU_POWER                      201
#define IDC_GROUPBOX_CHEATLIST          201
#define TXT_PAD2                        201
#define IDC_BUTTON_BROWSEFILE           201
#define IDC_CHECK_READONLY              201
#define BTN_PALETTE_RESET               201
#define CTL_PPUVIEW_TRACKBAR            201
#define IDC_NETMOO_PORT                 201
#define MENU_MV_EDIT_COPY               201
#define IDC_VIDEOCONFIG_YRES            201
#define IDC_DEBUGGER_FLAG_V             201
#define IDC_ADDBP_ADDR_END              201
#define IDC_NTVIEW_REFRESH_TRACKBAR     201
#define IDC_ASSEMBLER_APPLY             201
#define IDI_ICON4                       201
#define BUTTON_BATTERY                  201
#define BTN_CLEAR2                      201
#define MENU_EJECT_DISK                 202
#define TXT_FAM                         202
#define MENU_MV_EDIT_PASTE              202
#define IDC_VIDEOCONFIG_BPP             202
#define IDC_DEBUGGER_FLAG_U             202
#define IDC_ADDBP_CONDITION             202
#define IDC_ASSEMBLER_SAVE              202
#define IDD_TASEDITOR_NEWPROJECT        202
#define IDC_GROUPBOX_CHEATSEARCH        202
#define BUTTON_STATE                    202
#define MENU_SWITCH_DISK                203
#define IDC_NETMOO_NICK                 203
#define IDC_CHEAT_BOX_POSSIBILITIES     203
#define MENU_MV_EDIT_FIND               203
#define IDC_DEBUGGER_FLAG_B             203
#define IDC_ADDBP_NAME                  203
#define IDC_ASSEMBLER_UNDO              203
#define BUTTON_FDSBIOS                  203
#define MENU_INSERT_COIN                204
#define COMBO_NETMOO_LOCAL_PLAYERS      204
#define IDC_DEBUGGER_FLAG_D             204
#define IDC_GROUP_PREV_COM              204
#define BUTTON_SCREENSHOT               204
#define IDC_NETMOO_KEY                  205
#define IDC_DEBUGGER_FLAG_I             205
#define IDB_TE_GREEN_ARROW              205
#define BUTTON_CHEAT                    205
#define IDC_NETMOO_PASS                 206
#define IDC_DEBUGGER_FLAG_Z             206
#define BUTTON_MOVIE                    206
#define IDC_DEBUGGER_FLAG_C             207
#define BUTTON_MEMWATCH                 207
#define IDC_DEBUGGER_ENABLE_SYMBOLIC    208
#define IDB_TE_GREEN_BLUE_ARROW         208
#define BUTTON_BOT                      208
#define IDB_PIANO_0                     209
#define IDC_DEBUGGER_ROM_OFFSETS        209
#define BUTTON_MACRO                    209
#define IDB_PIANO_1                     210
#define BUTTON_PRESET                   210
#define IDB_PIANO_2                     211
#define BUTTON_LUA                      211
#define IDB_PIANO_3                     212
#define BUTTON_AVI                      212
#define IDB_PIANO_4                     213
#define BUTTON_ROOT                     213
#define IDB_PIANO_5                     214
#define IDB_PIANO_6                     215
#define IDB_PIANO_7                     216
#define IDB_PIANO_8                     217
#define IDB_PIANO_9                     218
#define IDB_PIANO_10                    219
#define IDB_PIANO_11                    220
#define IDB_PIANO_12                    221
#define IDB_PIANO_13                    222
#define IDB_PIANO_14                    223
#define IDB_PIANO_15                    224
#define IDB_PIANO_16                    225
#define IDB_PIANO_17                    226
#define IDB_PIANO_18                    227
#define IDB_PIANO_19                    228
#define IDB_PIANO_PLAYBACK_0            229
#define IDB_PIANO_PLAYBACK_1            230
#define IDB_PIANO_PLAYBACK_2            231
#define IDB_PIANO_PLAYBACK_3            232
#define IDB_PIANO_PLAYBACK_4            233
#define IDB_PIANO_PLAYBACK_5            234
#define IDB_PIANO_PLAYBACK_6            235
#define IDB_PIANO_PLAYBACK_7            236
#define IDB_PIANO_PLAYBACK_8            237
#define IDB_PIANO_PLAYBACK_9            238
#define IDB_PIANO_PLAYBACK_10           239
#define IDB_PIANO_PLAYBACK_11           240
#define IDB_PIANO_PLAYBACK_12           241
#define IDB_PIANO_PLAYBACK_13           242
#define IDB_PIANO_PLAYBACK_14           243
#define IDB_PIANO_PLAYBACK_15           244
#define IDB_PIANO_PLAYBACK_16           245
#define IDB_PIANO_PLAYBACK_17           246
#define IDB_PIANO_PLAYBACK_18           247
#define IDB_PIANO_PLAYBACK_19           248
#define IDB_PIANO_LOSTPOS_0             249
#define IDB_PIANO_LOSTPOS_1             250
#define BTN_NETMOO_CONNECT              250
#define IDB_PIANO_LOSTPOS_2             251
#define IDB_PIANO_LOSTPOS_3             252
#define IDB_PIANO_LOSTPOS_4             253
#define IDB_PIANO_LOSTPOS_5             254
#define IDB_PIANO_LOSTPOS_6             255
#define IDB_PIANO_LOSTPOS_7             256
#define IDB_PIANO_LOSTPOS_8             257
#define IDB_PIANO_LOSTPOS_9             258
#define IDB_PIANO_LOSTPOS_10            259
#define IDB_PIANO_LOSTPOS_11            260
#define IDB_PIANO_LOSTPOS_12            261
#define IDB_PIANO_LOSTPOS_13            262
#define IDB_PIANO_LOSTPOS_14            263
#define IDB_PIANO_LOSTPOS_15            264
#define IDB_PIANO_LOSTPOS_16            265
#define IDB_PIANO_LOSTPOS_17            266
#define IDB_PIANO_LOSTPOS_18            267
#define IDB_PIANO_LOSTPOS_19            268
#define IDB_BITMAP_SELECTED0            269
#define IDB_BITMAP_SELECTED1            270
#define IDB_BITMAP_SELECTED2            271
#define IDB_BITMAP_SELECTED3            272
#define IDB_BITMAP_SELECTED4            273
#define IDB_BITMAP_SELECTED5            274
#define IDB_BITMAP_SELECTED6            275
#define IDB_BITMAP_SELECTED7            276
#define IDB_BITMAP_SELECTED8            277
#define IDB_BITMAP_SELECTED9            278
#define IDB_BITMAP_SELECTED10           279
#define IDB_BITMAP_SELECTED11           280
#define IDB_BITMAP_SELECTED12           281
#define IDB_BITMAP_SELECTED13           282
#define IDB_BITMAP_SELECTED14           283
#define IDB_BITMAP_SELECTED15           284
#define IDB_BITMAP_SELECTED16           285
#define IDB_BITMAP_SELECTED17           286
#define IDB_BITMAP_SELECTED18           287
#define IDB_BITMAP_SELECTED19           288
#define IDD_TASEDITOR_SAVINGOPTIONS     289
#define IDD_SYMBOLIC_DEBUG_NAMING       290
#define DLG_SNESPAD                     291
#define MENU_HIDE_MENU                  300
#define COMBO_FILTER                    300
#define IDC_LABEL_LENGTH                300
#define MENU_MV_VIEW_RAM                300
#define IDC_DEBUGGER_DISASSEMBLY        300
#define IDC_ASSEMBLER_DEFPUSHBUTTON     300
#define MENU_RUN_IN_BACKGROUND          301
#define IDC_COMBO_RECORDFROM            301
#define IDC_LABEL_FRAMES                301
#define IDC_BTN_CHEAT_ADD               301
#define MENU_MV_VIEW_PPU                301
#define IDC_DEBUGGER_DISASSEMBLY_VSCR   301
#define MENU_BACKGROUND_INPUT           302
#define IDC_LABEL_UNDOCOUNT             302
#define IDC_BTN_CHEAT_DEL               302
#define IDC_DEBUGGER_BP_LIST            302
#define MENU_MV_VIEW_OAM                302
#define MENU_MV_VIEW_ROM                303
#define IDC_BTN_CHEAT_UPD               303
#define IDC_DEBUGGER_DISASSEMBLY_LEFT_PANEL 303
#define IDD_EDIT_HEADER                 303
#define MENU_ENABLE_AUTOSAVE            304
#define IDC_LABEL_ROMUSED               304
#define IDC_BTN_CHEAT_RESET             304
#define IDC_VIDEOCONFIG_SCALER_FS       304
#define IDC_DEBUGGER_VAL_A              304
#define IDC_LABEL_ROMCHECKSUM           305
#define IDC_BTN_CHEAT_KNOWN             305
#define IDC_DEBUGGER_VAL_X              305
#define IDC_LABEL_RECORDEDFROM          306
#define IDC_BTN_CHEAT_EQ                306
#define IDC_DEBUGGER_VAL_Y              306
#define IDC_LABEL_EMULATORUSED          307
#define IDC_BTN_CHEAT_NE                307
#define IDC_DEBUGGER_VAL_PC             307
#define IDC_LABEL_CURRCHECKSUM          308
#define IDC_BTN_CHEAT_GT                308
#define IDC_DEBUGGER_STACK_CONTENTS     308
#define IDC_BTN_CHEAT_LT                309
#define IDC_DEBUGGER_VAL_PCSEEK         309
#define IDC_LABEL_PALUSED               309
#define MENU_GAME_GENIE                 310
#define IDC_DEBUGGER_VAL_PPU            310
#define IDC_LABEL_NEWPPUUSED            310
#define IDC_DEBUGGER_VAL_SPR            311
#define IDC_BTN_CHEAT_ADDFROMFILE       311
#define IDC_DEBUGGER_BOOKMARK           312
#define DEBUGGERMENU                    312
#define IDC_DEBUGGER_CYCLES_EXCEED      313
#define IDC_DEBUGGER_INSTRUCTIONS_EXCEED 314
#define MENU_DIRECTORIES                320
#define MENU_INPUT                      321
#define MENU_GUI_OPTIONS                327
#define MENU_NTSC                       330
#define MENU_PAL                        331
#define MENU_DENDY                      332
#define MENU_MV_BOOKMARKS_RM_ALL        400
#define IDC_WINSIZE_MUL_X               400
#define IDC_CHEAT_CHECK_NE_BY           401
#define IDC_WINSIZE_MUL_Y               401
#define CHECK_ENABLE_FOURSCORE          401
#define IDC_DEBUGGER_STATUSFLAGS        401
#define IDC_CHEAT_CHECK_GT_BY           402
#define IDC_FORCE_INT_VIDEO_SCALARS     402
#define IDC_DEBUGGER_BREAKPOINTS        402
#define IDC_CHEAT_CHECK_LT_BY           403
#define IDC_FORCE_ASPECT_CORRECTION     403
#define IDC_DEBUGGER_VAL_S              403
#define IDC_TVASPECT_X                  404
#define IDC_DEBUGGER_VAL_S2             405
#define IDC_TVASPECT_Y                  405
#define IDC_VIDEOCONFIG_SCALER_WIN      406
#define CHECK_ENABLE_MICROPHONE         407
#define CTL_TINT_TRACKBAR               500
#define CTL_VOLUME_TRACKBAR             500
#define IDC_SCANLINE_FIRST_NTSC         500
#define IDC_SCANLINE_LAST_NTSC          501
#define CTL_HUE_TRACKBAR                501
#define IDC_DEBUGGER_VAL_SLINE          501
#define CTL_VOLUME_TRACKBAR_TRIANGLE    501
#define IDC_SCANLINE_FIRST_PAL          502
#define IDC_DEBUGGER_ADDR_LINE          502
#define CTL_VOLUME_TRACKBAR_SQUARE1     502
#define IDC_SCANLINE_LAST_PAL           503
#define CTL_VOLUME_TRACKBAR_SQUARE2     503
#define IDC_DEBUGGER_VAL_CYCLES_COUNT   503
#define CTL_VOLUME_TRACKBAR_NOISE       504
#define IDC_DEBUGGER_VAL_PPUPIXEL       504
#define CTL_VOLUME_TRACKBAR_PCM         505
#define IDC_DEBUGGER_VAL_CYCLES_COUNT2  505
#define IDC_DEBUGGER_VAL_INSTRUCTIONS_COUNT 506
#define IDC_DEBUGGER_VAL_INSTRUCTIONS_COUNT2 507
#define IDC_VIDEOCONFIG_NO8LIM          600
#define IDC_DEBUGGER_ROM_PATCHER        602
#define LIST_DEBUGGER_BOOKMARKS         701
#define BTN_CANCEL                      800
#define IDC_GAME_GENIE_CODE             1000
#define IDC_MEMVIEWFIND_WHAT            1000
#define IDC_BOOKMARK_DESCRIPTION        1000
#define MW_NAME00                       1000
#define MW_ADDR00                       1001
#define IDC_MEMVIEWFIND_TYPE_HEX        1001
#define IDC_NTVIEW_MIRROR_HORIZONTAL    1001
#define IDC_BOOKMARK_ADDRESS            1001
#define IDC_CHECK_STOPMOVIE             1002
#define IDC_GAME_GENIE_COMP             1002
#define IDC_MEMVIEWFIND_TYPE_TEXT       1002
#define IDC_NTVIEW_MIRROR_VERTICAL      1002
#define MW_VAL00                        1002
#define LV_MAPPING                      1003
#define IDC_EDIT_STOPFRAME              1003
#define IDC_GAME_GENIE_VAL              1003
#define IDC_MEMVIEWFIND_DIR_UP          1003
#define IDC_NTVIEW_MIRROR_FOUR_SCREEN   1003
#define MW_NAME01                       1003
#define MW_ADDR01                       1004
#define IDC_LIST_GGADDRESSES            1004
#define IDC_MEMVIEWFIND_DIR_DOWN        1004
#define IDC_NTVIEW_MIRROR_SS_TABLE_0    1004
#define IDC_BTN_ADD_TO_CHEATS           1005
#define IDC_MEMVIEWFIND_NEXT            1005
#define IDC_NTVIEW_MIRROR_SS_TABLE_1    1005
#define MW_VAL01                        1005
#define IDC_NTVIEW_MIRROR_SS_TABLE_2    1006
#define MW_NAME02                       1006
#define MW_ADDR02                       1007
#define IDC_NTVIEW_MIRROR_SS_TABLE_3    1007
#define IDC_NTVIEW_SHOW_SCROLL_LINES    1008
#define MW_VAL02                        1008
#define IDC_NTVIEW_SHOW_ATTRIBUTES      1009
#define MW_NAME03                       1009
#define IDC_NTVIEW_HIDE_PALETTES        1010
#define MW_ADDR03                       1010
#define IDC_BTN_CHEAT_EXPORTTOFILE      1011
#define MW_VAL03                        1011
#define IDSAVE                          1012
#define MW_NAME04                       1012
#define MW_ADDR04                       1013
#define IDC_CHECK1                      1013
#define IDC_CHEAT_AUTOLOADSAVE          1013
#define IDC_CHECK_SHORTCUT              1013
#define IDC_CHECK_SYMBOLIC_ARRAY        1013
#define IDC_RESTORE_BUTTON              1014
#define MW_VAL04                        1014
#define MW_NAME05                       1015
#define MW_ADDR05                       1016
#define IDC_EDIT_SHORTCUT0              1016
#define MW_VAL05                        1017
#define IDC_EDIT_SHORTCUT1              1017
#define IDC_CHECK_SYMBOLIC_DELETE       1017
#define IDC_PRGROM_COMBO                1018
#define MW_NAME06                       1018
#define IDC_EDIT_SHORTCUT2              1018
#define IDC_EDIT_SYMBOLIC_ARRAY         1018
#define MW_ADDR06                       1019
#define IDC_CHRROM_COMBO                1019
#define IDC_EDIT_SHORTCUT7              1019
#define IDC_RADIO_MIRR_HORIZONTAL       1020
#define MW_VAL06                        1020
#define IDC_EDIT_SHORTCUT6              1020
#define IDC_STATIC_SYMBOLIC_NAME        1020
#define IDC_RADIO_MIRR_VERTICAL         1021
#define MW_NAME07                       1021
#define IDC_EDIT6                       1021
#define IDC_EDIT_SHORTCUT9              1021
#define IDC_STATIC_SYMBOLIC_COMMENT     1021
#define MW_ADDR07                       1022
#define IDC_RADIO_MIRR_4SCREEN          1022
#define IDC_EDIT_SHORTCUT5              1022
#define IDC_STATIC_SYMBOLIC_ADDRESS     1022
#define MW_VAL07                        1023
#define IDC_EDIT_SHORTCUT4              1023
#define IDC_CHECK_SYMBOLIC_COMMENT_ARRAY_HEAD 1023
#define IDC_CHECK_TRAINER               1024
#define MW_NAME08                       1024
#define IDC_EDIT_SHORTCUT8              1024
#define IDC_CHECK_SYMBOLIC_COMMENT_OVERWRITE 1024
#define MW_ADDR08                       1025
#define IDC_PRGRAM_COMBO                1025
#define IDC_EDIT_SHORTCUT3              1025
#define IDC_CHECK4                      1025
#define IDC_MAPPER_COMBO                1026
#define MW_VAL08                        1026
#define IDC_CHECK_SYMBOLIC_OVERWRITE_NAME 1026
#define IDC_CHECK_SYMBOLIC_NAME_OVERWRITE 1026
#define IDC_SUBMAPPER_EDIT              1027
#define MW_NAME09                       1027
#define IDC_STATIC_SYMBOLIC_BYTE        1027
#define MW_ADDR09                       1028
#define IDC_CHRRAM_COMBO                1028
#define IDC_PRGNVRAM_COMBO              1029
#define MW_VAL09                        1029
#define IDC_STATIC_SYMBOLIC_INIT        1029
#define IDC_CHRNVRAM_COMBO              1030
#define MW_NAME10                       1030
#define MW_ADDR10                       1031
#define IDC_RADIO_REGION_NTSC           1031
#define IDC_RADIO_REGION_PAL            1032
#define MW_VAL10                        1032
#define IDC_RADIO_REGION_DUAL           1033
#define MW_NAME11                       1033
#define MW_ADDR11                       1034
#define IDC_ROM_FILE_EDIT               1034
#define MW_VAL11                        1035
#define IDC_EDIT2                       1035
#define IDC_HEX_HEADER_EDIT             1035
#define IDC_INPUT_DEVICE_COMBO          1036
#define MW_NAME12                       1036
#define MW_ADDR12                       1037
#define IDC_RADIO_REGION_DENDY          1037
#define IDC_RADIO_SYSTEM_NORMAL         1038
#define MW_VAL12                        1038
#define IDC_RADIO_SYSTEM_VS             1039
#define MW_NAME13                       1039
#define MW_ADDR13                       1040
#define IDC_RADIO_SYSTEM_PLAYCHOICE10   1040
#define IDC_RADIO_SYSTEM_EXTEND         1041
#define MW_VAL13                        1041
#define MW_NAME14                       1042
#define IDC_COMBO1                      1042
#define MW_ADDR14                       1043
#define IDC_SYSTEM_EXTEND_COMBO         1043
#define MW_VAL14                        1044
#define IDC_DEBUGGER_TEXT_SLINE         1044
#define MW_NAME15                       1045
#define IDC_DEBUGGER_TEXT_PPUPIXEL      1045
#define MW_ADDR15                       1046
#define IDC_VS_SYSTEM_COMBO             1046
#define IDC_DEBUGGER_TEXT_CYCLES_COUNT  1046
#define IDC_VS_PPU_COMBO                1047
#define MW_VAL15                        1047
#define IDC_DEBUGGER_TEXT_INSTRUCTIONS_COUNT 1047
#define MW_NAME16                       1048
#define IDC_DEBUGGER_VAL_S3             1048
#define MW_ADDR16                       1049
#define IDC_MAPPER_TEXT                 1049
#define IDC_DEBUGGER_TEXT_A             1049
#define IDC_SUBMAPPER_TEXT              1050
#define MW_VAL16                        1050
#define IDC_PRGROM_TEXT                 1051
#define MW_NAME17                       1051
#define MW_ADDR17                       1052
#define IDC_CHRROM_TEXT                 1053
#define MW_VAL17                        1053
#define MW_NAME18                       1054
#define MW_ADDR18                       1055
#define IDC_PRGRAM_TEXT                 1055
#define MW_VAL18                        1056
#define IDC_CHRRAM_TEXT                 1057
#define MW_NAME19                       1057
#define MW_ADDR19                       1058
#define IDC_PRGNVRAM_TEXT               1059
#define MW_VAL19                        1059
#define IDC_CHRNVRAM_TEXT               1060
#define MW_NAME20                       1060
#define MW_ADDR20                       1061
#define MW_VAL20                        1062
#define IDC_INESHEADER_GROUP            1063
#define MW_NAME21                       1063
#define MW_ADDR21                       1064
#define IDC_MIRRORING_GROUP             1064
#define IDC_REGION_GROUP                1065
#define MW_VAL21                        1065
#define IDC_SYSTEM_GROUP                1066
#define MW_NAME22                       1066
#define MW_ADDR22                       1067
#define IDC_VS_SYSTEM_GROUP             1067
#define IDC_VS_SYSTEM_TEXT              1068
#define MW_VAL22                        1068
#define IDC_VS_PPU_TEXT                 1069
#define MW_NAME23                       1069
#define MW_ADDR23                       1070
#define IDC_RADIO_VERSION_STANDARD      1071
#define MW_VAL23                        1071
#define IDC_RADIO_VERSION_INES20        1073
#define IDC_VERSION_GROUP               1074
#define IDC_MAPPER_GROUP                1075
#define IDC_CHECK_BATTERYNVRAM          1076
#define IDC_INPUT_DEVICE_TEXT           1077
#define IDC_PRG_GROUP                   1078
#define IDC_CHR_GROUP                   1079
#define IDC_UNOFFICIAL_GROUP            1081
#define IDC_CHECK_UNOFFICIAL_PRGRAM     1082
#define IDC_CHECK_UNOFFICIAL_EXTRA_REGION 1083
#define IDC_CHECK_UNOFFICIAL_BUS_CONFLICT 1084
#define IDC_CHECK_UNOFFICIAL            1085
#define IDC_MISCELLANEOUS_ROMS_TEXT     1086
#define IDC_MISCELLANEOUS_ROMS_EDIT     1087
#define IDC_EXTEND_SYSTEM_GROUP         1089
#define IDC_EXTEND_SYSTEM_TEXT          1090
#define IDC_CHEAT_SWITCH                1096
#define IDC_CHEAT_GLOBAL_SWITCH         1096
#define IDC_GAME_GENIE_LABEL            1097
#define IDC_CHEAT_GAME_GENIE_TEXT       1098
#define IDC_RADIO_SHORTCUT1             1100
#define IDC_RADIO_SHORTCUT2             1101
#define IDC_RADIO_SHORTCUT3             1102
#define IDC_RADIO_SHORTCUT4             1103
#define IDC_RADIO_SHORTCUT5             1104
#define IDC_RADIO_SHORTCUT6             1105
#define IDC_RADIO_SHORTCUT7             1106
#define IDC_RADIO_SHORTCUT8             1107
#define IDC_RADIO_SHORTCUT9             1108
#define IDC_RADIO_SHORTCUT0             1109
#define IDC_BOOKMARK_VIEW_TEXT          1110
#define IDC_BOOKMARK_COMBO_VIEW         1112
#define IDC_CHEAT_SHOWGG                1112
#define IDC_RADIO_BOOKMARKIMPORTOPTION_DISCARD 1114
#define IDC_RADIO_BOOKMARKIMPORTOPTION_BOOKMARKOVERWRITE 1115
#define IDC_RADIO_BOOKMARKIMPORTOPTION_BOOKMARKIGNORE 1116
#define BTN_ALLOW_LRUD                  1117
#define IDC_RADIO_BOOKMARKIMPORTOPTION_MERGE 1117
#define IDC_PRGROM_EDIT                 1118
#define IDC_RADIO_BOOKMARKIMPORTOPTION_SHORTCUTREASSIGN 1118
#define IDC_CHRROM_EDIT                 1119
#define BTN_PRESET_SET1                 1119
#define IDC_RADIO_BOOKMARKIMPORTOPTION_SHORTCUTKEEP 1119
#define BTN_PRESET_SET2                 1120
#define BTN_PRESET_SET3                 1121
#define IDC_CHECK_BOOKMARKIMPORTOPTION_CONFIRMEVERYTIMEONCONFLICT 1121
#define BTN_PRESET_IMPORT1              1122
#define IDC_TEXT_BOOKMARKIMPORTOPTION   1122
#define BTN_PRESET_IMPORT2              1123
#define IDC_TEXT_BOOKMARKIMPORTOPTION_BOOKMARK 1123
#define BTN_PRESET_IMPORT3              1124
#define IDC_TEXT_BOOKMARKIMPORTOPTION_SHORTCUT 1124
#define IDC_PRGRAM_EDIT                 1125
#define BTN_PRESET_EXPORT1              1125
#define IDC_GROUP_BOOKMARKIMPORTOPTION_SOLVECONFLICT 1125
#define BTN_PRESET_EXPORT2              1126
#define BTN_PRESET_EXPORT3              1127
#define IDC_CHRRAM_EDIT                 1128
#define IDC_PRGNVRAM_EDIT               1129
#define IDC_CHRNVRAM_EDIT               1130
#define IDC_LIST1                       1130
#define IDC_BUTTON_METADATA             1132
#define MEMW_EXPANDCOLLAPSE             1133
#define IDC_SOUND_RESTOREDEFAULTVOL     1133
#define TASEDITOR_REWIND                1133
#define TASEDITOR_FORWARD               1134
#define TASEDITOR_REWIND_FULL           1135
#define IDC_EDIT10                      1135
#define TASEDITOR_FORWARD_FULL          1136
#define TASEDITOR_PLAYSTOP              1137
#define IDC_RADIO_GREENZONE_SAVINGMODE_ALLFRAMES 1138
#define IDC_RADIO_UP                    1138
#define IDC_RADIO_ALL                   1139
#define IDC_RADIO_GREENZONE_SAVINGMODE_EVERY16FRAME 1139
#define IDC_RADIO_1P                    1140
#define IDC_RADIO_GREENZONE_SAVINGMODE_MARKEDFRAMES 1140
#define IDC_RADIO_2P                    1141
#define IDC_RADIO_GREENZONE_SAVINGMODE_DONTSAVE 1141
#define MEMW_EDIT00FORMULA              1142
#define IDC_RADIO_3P                    1142
#define MEMW_EDIT01FORMULA              1143
#define IDC_RADIO_4P                    1143
#define IDC_PROGRESS_BUTTON             1144
#define MEMW_EDIT02FORMULA              1144
#define MEMW_EDIT03FORMULA              1145
#define TASEDITOR_PREV_MARKER           1145
#define TASEDITOR_FIND_BEST_SIMILAR_MARKER 1146
#define IDC_SELECTION_MARKER_EDIT       1147
#define IDC_NOTE_TO_FIND                1147
#define IDC_AUTOSAVE_PERIOD             1147
#define IDC_EXTRA_SCANLINES             1147
#define IDC_CHEAT_TEXT                  1147
#define TASEDITOR_FIND_NEXT_SIMILAR_MARKER 1148
#define IDC_SYMBOLIC_ADDRESS            1148
#define IDC_VBLANK_SCANLINES            1148
#define IDC_HISTORYLIST                 1149
#define IDC_SYMBOLIC_NAME               1149
#define IDC_BOOKMARKSLIST               1150
#define IDC_SYMBOLIC_FILENAME           1150
#define TASEDITOR_NEXT_MARKER           1151
#define IDC_SYMBOLIC_COMMENT            1151
#define IDC_BRANCHES_BUTTON             1152
#define IDC_PLAYBACK_MARKER_EDIT        1154
#define TASEDITOR_RUN_MANUAL            1156
#define CHECK_SOUND_MUTETURBO           1179
#define IDC_EDIT_AUTHOR                 1180
#define MEMW_EDIT00RESET                1184
#define MEMW_EDIT01RESET                1185
#define MEMW_EDIT02RESET                1186
#define MEMW_EDIT03RESET                1187
#define MEMW_EDIT00RMADDRESS            1188
#define MEMW_EDIT01RMADDRESS            1189
#define MEMW_EDIT02RMADDRESS            1190
#define MEMW_EDIT03RMADDRESS            1191
#define IDC_MOVIE_CLOSE                 1192
#define EDIT00_RESULTS                  1193
#define IDC_MOVIE_PAUSEAFTERPLAYBACK    1193
#define EDIT01_RESULTS                  1194
#define IDC_MOVIE_BINDSAVESTATES        1194
#define EDIT02_RESULTS                  1195
#define EDIT03_RESULTS                  1196
#define IDC_MOVIE_DISPLAYSUBTITLES      1196
#define IDC_MOVIE_SUBTITLESINAVI        1197
#define IDC_MOVIE_AUTOBACKUP            1198
#define ID_SOUND_TRITOP                 1201
#define IDC_MOVIE_SUGGEST_READONLY      1201
#define ID_SOUND_QUALITYNOTIFY          1202
#define CB_ENABLECONTEXTMENU            1203
#define DEBUGAUTOLOAD                   1203
#define IDC_CHEAT_PAUSEWHENACTIVE       1203
#define IDC_FULLSAVESTATES              1203
#define IDC_SUPERIMPOSE                 1203
#define IDC_CHECK_BINARY                1203
#define IDC_NOTES_TO_SUBTITLES          1203
#define IDC_MATCH_CASE                  1203
#define IDC_COPY_INPUT                  1203
#define IDC_AUTORESUMECDLOGGING         1203
#define IDC_MASK_UNUSED_GRAPHICS        1203
#define CHECK_SOUND_SWAPDUTY            1203
#define CB_OVERCLOCKING                 1203
#define CHECK_DEEMPH_SWAP               1203
#define IDC_CHECK_LOG_BANK_NUMBER       1203
#define IDC_VOLUMEGROUP                 1204
#define IDC_CHECK_MARKERS               1204
#define IDC_RECORDING                   1204
#define IDC_COPY_MARKERS                1204
#define IDC_AUTOSAVECDL                 1204
#define IDC_INVERT_THE_MASK             1204
#define IDC_DEBUGGER_PREDEFINED_REGS    1204
#define IDC_RAMLIST                     1205
#define IDC_CHECK_BOOKMARKS             1205
#define IDC_RUN_AUTO                    1205
#define IDC_AUTOLOADCDL                 1205
#define IDC_SPRITE16_MODE               1205
#define IDC_C_SEARCH                    1206
#define IDC_USEPATTERN                  1206
#define IDC_C_ADDCHEAT                  1207
#define IDC_CHECK_HISTORY               1207
#define IDC_C_WATCH                     1208
#define IDC_CHECK_SELECTION             1208
#define IDC_C_RESET                     1209
#define IDC_CHECK_PIANO_ROLL            1209
#define IDC_C_ELIMINATE                 1210
#define IDC_LESSTHAN                    1211
#define IDC_MORETHAN                    1212
#define IDC_NOMORETHAN                  1213
#define IDC_NOLESSTHAN                  1214
#define IDC_EQUALTO                     1215
#define IDC_DIFFERENTFROM               1216
#define IDC_DIFFERENTBY                 1217
#define IDC_MODULO                      1218
#define IDC_EDIT_DIFFBY                 1219
#define IDC_EDIT_MODBY                  1220
#define IDC_PREVIOUSVALUE               1221
#define IDC_SPECIFICVALUE               1222
#define IDC_SPECIFICADDRESS             1223
#define IDC_NUMBEROFCHANGES             1224
#define IDC_EDIT_COMPAREVALUE           1225
#define IDC_EDIT_COMPAREADDRESS         1226
#define IDC_EDIT_COMPARECHANGES         1227
#define IDC_EDIT_COMPAREADDRESSES       1227
#define IDC_SIGNED                      1228
#define IDC_UNSIGNED                    1229
#define IDC_HEX                         1230
#define IDC_C_AUTOSEARCH                1231
#define IDC_1_BYTE                      1232
#define IDC_2_BYTES                     1233
#define IDC_4_BYTES                     1234
#define IDC_MISALIGN                    1235
#define IDC_C_RESET_CHANGES             1236
#define IDC_C_UNDO                      1237
#define IDC_WATCHLIST                   1238
#define IDC_C_HEXEDITOR                 1238
#define IDC_C_WATCH_EDIT                1239
#define IDC_C_WATCH_REMOVE              1240
#define IDC_C_WATCH_DUPLICATE           1241
#define ID_WATCHES_UPDOWN               1242
#define IDC_C_WATCH_UP                  1243
#define IDC_C_WATCH_DOWN                1244
#define IDC_PROMPT_TEXT                 1245
#define IDC_PROMPT_EDIT                 1247
#define IDC_BUTTON_LUABROWSE            1248
#define IDC_BUTTON_LUARUN               1249
#define IDC_BUTTON_LUASTOP              1250
#define IDC_EDIT_LUAPATH                1251
#define IDC_LUACONSOLE                  1252
#define IDC_BUTTON_LUAEDIT              1253
#define IDC_LUACONSOLE_CLEAR            1254
#define IDC_LUACONSOLE_CHOOSEFONT       1255
#define IDC_EDIT_LUAARGS                1256
#define CB_PARTIALVISUALTHEME           1257
#define DEBUGLOADDEB                    1258
#define IDC_C_SEARCHROM                 1258
#define IDC_SINGLEINSTANCE              1258
#define IDC_MOVIE_CLOSEAFTERPLAYBACK    1258
#define IDC_C_WATCH_SEPARATE            1259
#define CHECK_AUTORESTORE_PLAYBACK      1261
#define CB_FS_BY_DOUBLECLICK            1261
#define IDC_PROGRESS1                   1262
#define CHECK_FOLLOW_CURSOR             1263
#define IDC_BOOKMARKS_BOX               1264
#define IDC_BRANCHES_BITMAP             1265
#define CHECK_TURBO_SEEK                1266
#define IDC_TEXT_SELECTION              1267
#define IDC_TEXT_CLIPBOARD              1268
#define IDC_RADIO_1PLAYER               1269
#define IDC_RADIO_2PLAYERS              1270
#define IDC_PLAYBACK_MARKER             1270
#define IDC_RADIO_FOURSCORE             1271
#define IDC_SELECTION_MARKER            1271
#define IDC_RADIO_DOWN                  1273
#define IDC_PLAYBACK_BOX                1275
#define IDC_RECORDER_BOX                1276
#define IDC_SPLICER_BOX                 1277
#define IDC_LUA_BOX                     1278
#define IDC_HISTORY_BOX                 1279
#define IDC_TASEDITOR_NAME              1280
#define ID_CANCEL                       1281
#define IDC_AUTOSAVE_PROJECT            1282
#define IDC_SILENT_AUTOSAVE             1283
#define ID_CHR1                         1283
#define ID_CHR2                         1284
#define ID_CHR3                         1285
#define ID_STATIC                       1286
#define CTL_PALSAT_TRACKBAR             1291
#define CB_SKIP_7BIT                    1293
#define STATIC_SATVALUE                 1294
#define CTL_PALNOTCH_TRACKBAR           1295
#define STATIC_NOTCHVALUE               1296
#define CTL_PALSHARP_TRACKBAR           1297
#define STATIC_SHARPVALUE               1298
#define CTL_PALCONTRAST_TRACKBAR        1299
#define STATIC_CONTRASTVALUE            1300
#define CTL_PALBRIGHT_TRACKBAR          1301
#define STATIC_BRIGHTVALUE              1302
#define DEBUGIDAFONT                    1305
#define IDC_AUTOSAVE_PERIOD_EVERY_TEXT  1306
#define IDC_AUTOSAVE_PERIOD_MINUTES_TEXT 1307
#define IDC_VBLANK_SCANLINES_TEXT       1308
#define IDC_EXTRA_SCANLINES_TEXT        1309
#define IDC_DATASIZE_GROUPBOX           1310
#define IDC_DATATYPE_GROUPBOX           1311
#define IDC_CHEAT_CODE_LABEL            1312
#define IDC_CHEAT_ADDRESS_LABEL         1313
#define IDC_CHEAT_VAL_LABEL             1314
#define IDC_CHEAT_COM_LABEL             1315
#define IDC_CHEAT_LABEL_KNOWN           1316
#define IDC_BINARY                      1317
#define IDC_GAME_GENIE_ADDR             1501
#define IDC_EDIT_SYMBOLIC_INIT          1502
#define BTN_SAVE                        1503
#define MENU_INESHEADEREDITOR           40001
#define MENU_INPUT_BARCODE              40004
#define ID_BOOKMARKS_IMPORT             40005
#define ID_BOOKMARKS_SAVEAS             40006
#define ID_BOOKMARKS_OPTION             40007
#define ID_BOOKMARKS_EXPORT             40008
#define ID_HEXEDITOR_DEFCOLOR           40009
#define ID_CDLOGGER_DEFCOLOR            40010
#define ID_DEBUGGER_DEFCOLOR            40011
#define ID_Menu                         40012
#define MENU_INSERT_COIN2               40013
#define MENU_SERVICE                    40014
#define MENU_SERVICE_BUTTON             40015
#define MENU_NETWORK                    40040
#define MENU_PALETTE                    40041
#define MENU_SOUND                      40042
#define MENU_TIMING                     40043
#define MENU_VIDEO                      40044
#define MENU_HOTKEYS                    40045
#define MENU_ABOUT                      40046
#define MENU_MSGLOG                     40047
#define MENU_CHEATS                     40048
#define MENU_AUTOFIRE_PATTERN_1         40050
#define MENU_AUTOFIRE_PATTERN_2         40051
#define MENU_AUTOFIRE_PATTERN_3         40052
#define ID_DEBUG_DEBUGGER               40053
#define MENU_AUTOFIRE_PATTERN_4         40053
#define ID_DEBUG_PPUVIEWER              40054
#define MENU_AUTOFIRE_PATTERN_5         40054
#define ID_DEBUG_NAMETABLEVIEWER        40055
#define MENU_AUTOFIRE_PATTERN_6         40055
#define ID_DEBUG_HEXEDITOR              40056
#define MENU_AUTOFIRE_PATTERN_7         40056
#define ID_DEBUG_TRACELOGGER            40057
#define MENU_AUTOFIRE_PATTERN_8         40057
#define MENU_AUTOFIRE_PATTERN_9         40058
#define ID_DEBUG_GAMEGENIEDECODER       40059
#define MENU_AUTOFIRE_PATTERN_10        40059
#define ID_DEBUG_CDLOGGER               40060
#define MENU_AUTOFIRE_PATTERN_11        40060
#define MENU_AUTOFIRE_PATTERN_12        40061
#define MENU_AUTOFIRE_PATTERN_13        40062
#define MENU_AUTOFIRE_PATTERN_14        40063
#define MENU_AUTOFIRE_PATTERN_15        40064
#define MENU_AUTOFIRE_OFFSET_1          40065
#define MENU_AUTOFIRE_OFFSET_2          40066
#define MENU_AUTOFIRE_OFFSET_3          40067
#define MENU_AUTOFIRE_OFFSET_4          40068
#define MENU_AUTOFIRE_OFFSET_5          40069
#define MENU_AUTOFIRE_OFFSET_6          40070
#define MENU_ALTERNATE_AB               40071
#define MENU_PPUVIEWER                  40074
#define MENU_NAMETABLEVIEWER            40075
#define MENU_HEXEDITOR                  40076
#define MENU_TRACELOGGER                40077
#define MENU_CDLOGGER                   40078
#define MENU_GAMEGENIEDECODER           40079
#define MENU_DEBUGGER                   40080
#define MENU_MEMORY_WATCH               40081
#define ID_FILE_RECENT                  40100
#define MEMW_HELP_WCOMMANDS             40101
#define MEMW_OPTIONS_LOADLASTFILE       40102
#define MEMW_FILE_NEW                   40103
#define MEMW_FILE_OPEN                  40104
#define MEMW_FILE_SAVE                  40105
#define MEMW_FILE_SAVEAS                40106
#define MEMW_FILE_CLOSE                 40108
#define MEMW_OPTIONS_LOADSTART          40109
#define ID_FILE_RECORDMODE_TRUNCATE     40110
#define ID_FILE_RECORDMODE_OVERWRITE    40111
#define ID_FILE_RECORDMODE_INSERT       40112
#define FCEUX_CONTEXT_RECORDMODE_TRUNCATE 40115
#define FCEUX_CONTEXT_RECORDMODE_OVERWRITE 40116
#define FCEUX_CONTEXT_RECORDMODE_INSERT 40117
#define MENU_RECORD_WAV                 40120
#define MENU_STOP_WAV                   40121
#define ID_FILE_NEXTRECORDMODE          40127
#define ID_FILE_PREVRECORDMODE          40128
#define ACCEL_CTRL_O                    40130
#define ACCEL_CTRL_W                    40132
#define ACCEL_CTRL_S                    40134
#define ACCEL_CTRL_SHIFT_S              40135
#define ACCEL_CTRL_N                    40136
#define ACCEL_CTRL_C                    40138
#define MENU_HELP                       40140
#define MENU_DISPLAY_BG                 40147
#define MENU_DISPLAY_OBJ                40148
#define MENU_CONVERT_MOVIE              40150
#define ID_TOOLS_TEXTHOOKER             40158
#define ID_EDIT_DELETE                  40169
#define ID_FILE_SAVEPROJECT             40172
#define ID_EDIT_TRUNCATE                40177
#define ID_FILE_IMPORT                  40178
#define ID_FILE_OPENPROJECT             40181
#define ID_FILE_SAVEPROJECTAS           40182
#define ID_FILE_EXPORTFM2               40183
#define ACCEL_CTRL_X                    40184
#define ACCEL_CTRL_V                    40195
#define ACCEL_CTRL_SHIFT_V              40196
#define ACCEL_CTRL_DELETE               40197
#define ACCEL_CTRL_B                    40199
#define ID_CONTEXT_SELECTED_TRUNCATE    40200
#define ID_CONTEXT_SELECTED_INSERTFRAMES 40204
#define ID_CONTEXT_SELECTED_DELETEFRAMES 40205
#define ID_EDIT_SELECTALL               40214
#define ID_MEMWVIEW_FILE_CLOSE          40217
#define MENU_MV_FILE_GOTO_ADDRESS       40219
#define ID_FILE_TRUNCATE_MOVIE          40221
#define FCEUX_CONTEXT_TRUNCATE_MOVIE    40222
#define ID_FILE_INSERT_1_FRAME          40223
#define FCEUX_CONTEXT_INSERT_1_FRAME    40224
#define ID_FILE_DELETE_1_FRAME          40225
#define FCEUX_CONTEXT_DELETE_1_FRAME    40226
#define ID_FILE_OPENLUAWINDOW           40229
#define ID_FILE_CLOSELUAWINDOWS         40230
#define MENU_DISPLAY_LAGCOUNTER         40237
#define MENU_DISPLAY_FA_LAGSKIP         40239
#define MENU_INPUTDISPLAY_0             40250
#define MENU_INPUTDISPLAY_1             40251
#define MENU_INPUTDISPLAY_2             40252
#define MENU_INPUTDISPLAY_4             40253
#define ID_DISPLAY_FRAMECOUNTER         40254
#define MENU_CONFIG_BINDSAVES           40256
#define MENU_MV_HELP                    40258
#define ID_NES_PAUSE                    40263
#define ID_NES_SPEEDUP                  40265
#define ID_NES_SLOWDOWN                 40266
#define ID_NES_NORMALSPEED              40268
#define ID_NES_TURBO                    40269
#define ID_NES_SLOWESTSPEED             40270
#define ID_FILE_SCREENSHOT              40272
#define ID_FILE_PLAYMOVIEFROMBEGINNING  40274
#define FCEU_CONTEXT_MOVIEHELP          40281
#define FCEUX_CONTEXT_REPLAYMOVIE       40282
#define FCEU_CONTEXT_OPENROM            40286
#define FCEU_CONTEXT_FCEUHELP           40287
#define FCEU_CONTEXT_PLAYMOVIEFROMBEGINNING 40295
#define FCEU_CONTEXT_STOPMOVIE          40296
#define FCEU_CONTEXT_CLOSEROM           40298
#define FCEUX_CONTEXT_RECORDMOVIE       40303
#define FCEUX_CONTEXT_SCREENSHOT        40305
#define FCEUX_CONTEXT_REWINDTOLASTAUTO  40307
#define FCEUX_CONTEXT_VIEWCOMMENTSSUBTITLES 40311
#define MEMW_OPTIONS_EXPANDCOLLAPSE     40314
#define FCEUX_CONTEXT_UNDOLOADSTATE     40316
#define FCEUX_CONTEXT_MAKEBACKUP        40320
#define MENU_MOVIEOPTIONS               40322
#define FCEUX_CONTEXT_UNDOSAVESTATE     40324
#define FCEUX_CONTEXT_RECENTROM1        40328
#define ID_FILE_MOVIE_TOGGLEREAD        40331
#define FCEUX_CONTEXT_READONLYTOGGLE    40335
#define MENU_LOADSTATE                  40343
#define MENU_SAVESTATE                  40344
#define MENU_NEXTSAVESTATE              40347
#define MENU_PREVIOUSSAVESTATE          40348
#define MENU_VIEWSAVESLOTS              40350
#define MENU_LUA_RECENT                 40352
#define MENU_MOVIE_RECENT               40354
#define FCEUX_CONTEXT_LOADLASTMOVIE     40356
#define FCEUX_CONTEXT_SAVEMOVIEAS       40358
#define ID_FILE_TOGGLE_RECORDING_MOVIE  40359
#define FCEUX_CONTEXT_TOGGLE_RECORDING  40360
#define ID_OPTIONS_BINDTOMAINWINDOW     40361
#define ID_NEWPPU                       40365
#define ID_OLDPPU                       40366
#define ID_CONFIG_SAVECONFIGFILE        40367
#define RAMMENU_FILE_AUTOLOAD           40368
#define RAMMENU_FILE_SAVEWINDOW         40369
#define RAMMENU_FILE_SAVE               40370
#define RAMMENU_FILE_SAVEAS             40371
#define RAMMENU_FILE_OPEN               40372
#define RAMMENU_FILE_APPEND             40373
#define RAMMENU_FILE_NEW                40374
#define RAMMENU_FILE_RECENT             40375
#define ID_RAM_SEARCH                   40376
#define ID_RAM_WATCH                    40377
#define RW_MENU_FIRST_RECENT_FILE       40380
#define RW_MENU_LAST_RECENT_FILE        40400
#define ID_ENABLE_BACKUPSAVESTATES      40401
#define ID_ENABLE_COMPRESSSAVESTATES    40402
#define ID_AVI_DISMOVIEMESSAGE          40405
#define ID_INPUTDISPLAY_OLDSTYLEDISP    40406
#define ID_CONTEXT_FULLSAVESTATES       40409
#define ID_FILE_SAVESCREENSHOTAS        40411
#define FCEUX_CONTEXT_GUICONFIG         40418
#define ID_CONTEXT_SELECTED_INSERTFRAMES2 40425
#define ACCEL_CTRL_F                    40429
#define ID_CONFIG_SETGREENZONECAPACITY  40432
#define ACCEL_CTRL_INSERT               40433
#define ID_DISPLAY_RERECORDCOUNTER      40436
#define ID_DISPLAY_MOVIESTATUSICON      40437
#define ID_AVI_ENABLEHUDRECORDING       40440
#define ACCEL_INS                       40442
#define ACCEL_DEL                       40443
#define ID_CONTEXT_SELECTED_CLEARFRAMES 40447
#define ID_EDIT_CLEAR                   40450
#define ID_EDIT_INSERTFRAMES            40451
#define ID_EDIT_INSERT                  40452
#define ID_CONFIG_BINDMARKERSTOINPUT    40454
#define ACCEL_CTRL_A                    40455
#define ID_EDIT_SELECTMIDMARKERS        40457
#define ID_SELECTED_SELECTMIDMARKERS    40458
#define ID_EDIT_CLONEFRAMES             40460
#define ACCEL_CTRL_SHIFT_INS            40461
#define ID_SELECTED_CLONE               40463
#define ACCEL_CTRL_Z                    40465
#define ACCEL_CTRL_Y                    40466
#define ID_EDIT_UNDO                    40468
#define ID_EDIT_REDO                    40469
#define ID_CONFIG_SETMAXUNDOLEVELS      40470
#define ID_VIEW_JUMPWHENMAKINGUNDO      40472
#define ID_CONFIG_BRANCHESRESTOREFULLMOVIE 40473
#define ID_CONFIG_OLDBRANCHINGCONTROLS  40474
#define ID_CONFIG_HUDINBRANCHSCREENSHOTS 40475
#define ACCEL_CTRL_Q                    40478
#define ID_EDIT_SELECTIONUNDO           40481
#define ID_EDIT_SELECTIONREDO           40482
#define ID_EDIT_RESELECTCLIPBOARD       40483
#define ID_FILE_SAVECOMPACT             40484
#define ID_HELP_ABOUT                   40485
#define ID_VIEW_ENABLEHOTCHANGES        40488
#define ID_VIEW_SHOWBRANCHSCREENSHOTS   40489
#define ID_CONFIG_USE1PFORRECORDING     40491
#define ID_CONFIG_COMBINECONSECUTIVERECORDINGS 40492
#define ID_EDIT_PASTEINSERT             40495
#define ACCEL_CTRL_PGUP                 40502
#define ACCEL_CTRL_PGDN                 40503
#define ACCEL_SHIFT_PGUP                40504
#define ACCEL_SHIFT_PGDN                40505
#define ID_VIEW_FOLLOWMARKERNOTECONTEXT 40507
#define ID_VIEW_SHOWBRANCHTOOLTIPS      40508
#define ID_CONFIG_USEINPUTKEYSFORCOLUMNSET 40509
#define ID_CONFIG_EMPTYNEWMARKERNOTES   40510
#define ID_VIEW_FINDNOTE                40515
#define ID_FILE_CLOSE                   40517
#define ID_EDIT_PASTE                   40520
#define ID_EDIT_COPY                    40521
#define ID_EDIT_CUT                     40522
#define MENU_TASEDITOR                  40524
#define ID_FILE_NEW                     40525
#define ID_HELP_TOOLTIPS                40527
#define ID_PATTERN_TEST                 40534
#define ID_EDIT_DESELECT                40536
#define ID_SELECTED_DESELECT            40537
#define ID_CONFIG_DRAWINPUTBYDRAGGING   40539
#define ACCEL_CTRL_UP                   40541
#define ACCEL_CTRL_DOWN                 40542
#define ACCEL_CTRL_LEFT                 40543
#define ACCEL_CTRL_RIGHT                40544
#define ACCEL_HOME                      40545
#define ACCEL_END                       40546
#define ACCEL_PGUP                      40547
#define ACCEL_PGDN                      40548
#define ACCEL_CTRL_HOME                 40550
#define ACCEL_CTRL_END                  40551
#define ACCEL_SHIFT_HOME                40552
#define ACCEL_SHIFT_END                 40553
#define ACCEL_SHIFT_UP                  40554
#define ACCEL_SHIFT_DOWN                40555
#define ACCEL_SHIFT_LEFT                40556
#define ACCEL_SHIFT_RIGHT               40557
#define ID_CONFIG_AUTOPAUSEATTHEENDOFMOVIE 40559
#define ID_SELECTED_SETMARKERS          40560
#define ID_SELECTED_REMOVEMARKERS       40561
#define ID_HELP_OPEN_MANUAL             40564
#define ID_DISPLAY_FPS                  40565
#define ID_CONFIG_ADJUSTLAG             40567
#define ID_CONFIG_PATTERNSKIPSLAG       40568
#define CLEAR_LOG                       40569
#define CLOSE_LOG                       40570
#define ID_SELECTED_UNGREENZONE         40571
#define CHEAT_CONTEXT_POSSI_GOTOINHEXEDITOR 40572
#define ID_CONFIG_ENABLEGREENZONING     40573
#define ID_EMULATIONSPEED_SETFRAMEADVANCEDELAY 40574
#define ID_EMULATIONSPEED_SETCUSTOMSPEEDFORFRAMEADVANCE 40576
#define ID_EMULATIONSPEED_CUSTOMSPEED   40577
#define ID_ENABLE_AUTORESUME            40579
#define ID_CONFIG_SAVING_OPTIONS        40581
#define ID_CDLFILENAME                  40582
#define ID_HIGHLIGHTING_FADEWHENPAUSED  40586
#define ID_HIGHLIGHTING_SETFADINGPERIOD 40587
#define ID_HIGHLIGHTING_HIGHLIGHT_ACTIVITY 40588
#define MENU_MV_FILE_DUMP_64K           40590
#define MENU_MV_FILE_DUMP_OAM           40592
#define MENU_RAMINIT_DEFAULT            40593
#define MENU_RAMINIT_FF                 40594
#define MENU_RAMINIT_00                 40595
#define MENU_RAMINIT_RANDOM             40596
#define MENU_MV_FILE_LOAD_RAM           40597
#define MENU_MV_FILE_LOAD_PPU           40598
#define DISASM_CONTEXT_COPY             40598
#define MENU_MV_FILE_LOAD_OAM           40599
#define DISASM_CONTEXT_SELECTALL        40599
#define CHEAT_CONTEXT_POSSI_ADDTOMEMORYWATCH 40600
#define CHEAT_CONTEXT_POSSI_ADDCHEAT    40601
#define CHEAT_CONTEXT_POSSI_ADDTORAMWATCH 40603
#define IDC_DEBUGGER_BOOKMARKS          45535
#define MW_VALUELABEL2                  65423
#define MW_VALUELABEL1                  65426
#define IDC_STATIC_SLASHTEXT            65442
#define IDC_DEBUGGER_TEXT_SPR           65530
#define IDC_DEBUGGER_TEXT_PPU           65531
#define IDC_BOOKMARK_NAME_TEXT          65532
#define IDC_DEBUGGER_TEXT_PC            65532
#define IDC_BOOKMARK_ADDRESS_TEXT       65533
#define IDC_DEBUGGER_TEXT_Y             65533
#define IDC_NTVIEW_SCANLINE_TEXT        65534
#define IDC_BOOKMARK_SHORTCUT_PREFIX_TEXT 65534
#define IDC_DEBUGGER_TEXT_X             65534

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        313
#define _APS_NEXT_COMMAND_VALUE         40016
#define _APS_NEXT_CONTROL_VALUE         1050
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
